@@ -45,7 +45,6 @@ import org.apache.maven.artifact.resolver.ArtifactResolver;
 import org.apache.maven.artifact.versioning.VersionRange;
 import org.apache.maven.plugin.MojoExecutionException;
 import org.apache.maven.plugins.annotations.Component;
-import org.apache.maven.plugins.annotations.Execute;
 import org.apache.maven.plugins.annotations.LifecyclePhase;
 import org.apache.maven.plugins.annotations.Mojo;
 import org.apache.maven.plugins.annotations.Parameter;
@@ -65,12 +64,11 @@ import aQute.bnd.osgi.Jar;
 
 /**
  * Build an OSGi bundle jar for all transitive dependencies.
- * 
+ *
  * @deprecated The bundleall goal is no longer supported and may be removed in a future release
  */
 @Deprecated
-@Mojo( name = "bundleall", requiresDependencyResolution = ResolutionScope.TEST )
-@Execute( phase = LifecyclePhase.PACKAGE )
+@Mojo( name = "bundleall", requiresDependencyResolution = ResolutionScope.TEST, defaultPhase = LifecyclePhase.PACKAGE )
 public class BundleAllPlugin extends ManifestPlugin
 {
     private static final String LS = System.getProperty( "line.separator" );
@@ -126,12 +124,13 @@ public class BundleAllPlugin extends ManifestPlugin
     private Set m_artifactsBeingProcessed = new HashSet();
 
     /**
-     * Process up to some depth 
+     * Process up to some depth
      */
     @Parameter
     private int depth = Integer.MAX_VALUE;
 
 
+    @Override
     public void execute() throws MojoExecutionException
     {
         getLog().warn( "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~" );
@@ -145,7 +144,7 @@ public class BundleAllPlugin extends ManifestPlugin
 
     /**
      * Bundle a project and all its dependencies
-     * 
+     *
      * @param project
      * @throws MojoExecutionException
      */
@@ -157,7 +156,7 @@ public class BundleAllPlugin extends ManifestPlugin
 
     /**
      * Bundle a project and its transitive dependencies up to some depth level
-     * 
+     *
      * @param project
      * @param maxDepth how deep to process the dependency tree
      * @throws MojoExecutionException
@@ -290,7 +289,7 @@ public class BundleAllPlugin extends ManifestPlugin
 
     /**
      * Bundle the root of a dependency tree after all its children have been bundled
-     * 
+     *
      * @param project
      * @param bundleInfo
      * @return
@@ -315,7 +314,7 @@ public class BundleAllPlugin extends ManifestPlugin
 
     /**
      * Bundle one project only without building its childre
-     * 
+     *
      * @param project
      * @throws MojoExecutionException
      */
@@ -330,7 +329,7 @@ public class BundleAllPlugin extends ManifestPlugin
             instructions.put( Analyzer.IMPORT_PACKAGE, wrapImportPackage );
 
             project.getArtifact().setFile( getFile( artifact ) );
-            File outputFile = getOutputFile( artifact );
+            File outputFile = getOutputFile(artifact);
 
             if ( project.getArtifact().getFile().equals( outputFile ) )
             {
@@ -343,7 +342,8 @@ public class BundleAllPlugin extends ManifestPlugin
                 //                    + " to the same file, try cleaning: " + outputFile );
             }
 
-            Analyzer analyzer = getAnalyzer( project, instructions, new Properties(), getClasspath( project ) );
+            org.apache.maven.shared.dependency.graph.DependencyNode dependencyGraph = buildDependencyGraph( project );
+            Analyzer analyzer = getAnalyzer( project, dependencyGraph, instructions, new Properties(), getClasspath( project, dependencyGraph ) );
 
             Jar osgiJar = new Jar( project.getArtifactId(), project.getArtifact().getFile() );
 
@@ -428,9 +428,10 @@ public class BundleAllPlugin extends ManifestPlugin
 
     /**
      * Use previously built bundles when available.
-     * 
+     *
      * @param artifact
      */
+    @Override
     protected File getFile( final Artifact artifact )
     {
         File bundle = getBuiltFile( artifact );
@@ -457,7 +458,7 @@ public class BundleAllPlugin extends ManifestPlugin
 
         /*
          * Find snapshots in output folder, eg. 2.1-SNAPSHOT will match 2.1.0.20070207_193904_2
-         * TODO there has to be another way to do this using Maven libs 
+         * TODO there has to be another way to do this using Maven libs
          */
         if ( ( bundle == null ) && artifact.isSnapshot() )
         {
@@ -495,9 +496,9 @@ public class BundleAllPlugin extends ManifestPlugin
     /**
      * Check that the bundleName provided correspond to the artifact provided.
      * Used to determine when the bundle name is a timestamped snapshot and the artifact is a snapshot not timestamped.
-     * 
+     *
      * @param artifact artifact with snapshot version
-     * @param bundleName bundle file name 
+     * @param bundleName bundle file name
      * @return if both represent the same artifact and version, forgetting about the snapshot timestamp
      */
     protected boolean snapshotMatch( Artifact artifact, String bundleName )
